==> nextcloudtalkbot-0.0.45.tar.gz: nextcloudtalkbot-0.0.45/README.md <==
# Nextcloud Talk Bot

Python3 library for creating a Nextcloud Talk bot. 

This repository contains the code for a Nextcloud Talk bot that can perform various actions in a Nextcloud Talk room, such as sending files and listing activities.

## Installation

Via PIP:

```
pip install nextcloudtalkbot
```

or manually:

Clone this repository:

```
git clone https://github.com/sowoi/nextcloud-talk-bot.git
```

## NLP

To use Spacy as a Natural Language Processor, it is necessary to download a model.

```
python -m spacy download en_core_web_sm
```
The command downloads the model for the English language file. 


## Documentation

Documentation can be found at [readthedocs.org](https://nextcloud-talk-bot.readthedocs.io).

## Translations

This project uses weblate for translation.


## License

Licensed under the terms of GNU General Public License v3.0. See LICENSE file.


## Developer-Website

[https://okxo.de](https://okxo.de)


![Linting](https://github.com/sowoi/nextcloud-talk-bot//actions/workflows/python-lint.yml/badge.svg)
![Unittests](https://github.com/sowoi/nextcloud-talk-bot//actions/workflows/python-tox.yml/badge.svg)
[![CodeQL](https://github.com/sowoi/nextcloud-talk-bot/actions/workflows/github-code-scanning/codeql/badge.svg)](https://github.com/sowoi/nextcloud-talk-bot/actions/workflows/github-code-scanning/codeql)
![License](https://img.shields.io/pypi/l/nextcloudtalkbot?style=plastic)
![Dependencies](https://img.shields.io/librariesio/github/sowoi/nextcloud-talk-bot?style=plastic)
![Versions](https://img.shields.io/pypi/pyversions/nextcloudtalkbot?style=plastic)
![Release](https://img.shields.io/pypi/status/nextcloudtalkbot?style=plastic)
![Docs](https://readthedocs.org/projects/nextcloud-talk-bot/badge/?version=latest&style=plactic)

==> nextcloudtalkbot-0.0.46.tar.gz: nextcloudtalkbot-0.0.46/README.md <==
# Nextcloud Talk Bot

Python 3 library for creating a Nextcloud Talk bot. 

This repository contains the code for a Nextcloud Talk bot that can perform various actions in a Nextcloud Talk room, such as sending files and listing activities.

## Installation

Via PIP:

```
pip install nextcloudtalkbot
```

or manually:

Clone this repository:

```
git clone https://github.com/sowoi/nextcloud-talk-bot.git
```

## NLP

To use Spacy as a Natural Language Processor, it is necessary to download a model.

```
python -m spacy download en_core_web_sm
```
The command downloads the model for the English language file. 


## Documentation

Documentation can be found at [readthedocs.org](https://nextcloud-talk-bot.readthedocs.io).

## Translations

This project uses [Hosted Weblate](https://hosted.weblate.org/engage/nextcloudtalkbot/) for translation.


## License

Licensed under the terms of GNU General Public License v3.0. See LICENSE file.


## Developer-Website

[https://okxo.de](https://okxo.de)


![Linting](https://github.com/sowoi/nextcloud-talk-bot//actions/workflows/python-lint.yml/badge.svg)
![Unittests](https://github.com/sowoi/nextcloud-talk-bot//actions/workflows/python-tox.yml/badge.svg)
[![CodeQL](https://github.com/sowoi/nextcloud-talk-bot/actions/workflows/github-code-scanning/codeql/badge.svg)](https://github.com/sowoi/nextcloud-talk-bot/actions/workflows/github-code-scanning/codeql)
![License](https://img.shields.io/pypi/l/nextcloudtalkbot?style=plastic)
![Dependencies](https://img.shields.io/librariesio/github/sowoi/nextcloud-talk-bot?style=plastic)
![Versions](https://img.shields.io/pypi/pyversions/nextcloudtalkbot?style=plastic)
![Release](https://img.shields.io/pypi/status/nextcloudtalkbot?style=plastic)
![Docs](https://readthedocs.org/projects/nextcloud-talk-bot/badge/?version=latest&style=plactic)
![Translations](https://hosted.weblate.org/widgets/nextcloudtalkbot/-/svg-badge.svg)
